@@ -67,11 +67,20 @@ class QuantumSystem(DispatchClient, ABC):
     # To facilitate warnings in set_units, introduce a counter keeping track of the
     # number of QuantumSystem instances
     _quantumsystem_counter: int = 0
+    # To enable autogeneration of id_str, keep a record of all subclass types and
+    # corresponding counts of instances
+    _instance_counter: Dict[str, int] = {}
 
     subclasses: List[ABCMeta] = []
 
     def __new__(cls, *args, **kwargs) -> "QuantumSystem":
         QuantumSystem._quantumsystem_counter += 1
+
+        if cls.__name__ not in QuantumSystem._instance_counter:
+            QuantumSystem._instance_counter[cls.__name__] = 1
+        else:
+            QuantumSystem._instance_counter[cls.__name__] += 1
+
         return super().__new__(cls)
 
     def __del__(self) -> None:
@@ -84,6 +93,10 @@ class QuantumSystem(DispatchClient, ABC):
         except (NameError, AttributeError):
             pass
 
+    def __init__(self, id_str: Union[str, None]):
+        self._sys_type = type(self).__name__
+        self._id_str = id_str or self._autogenerate_id_str()
+
     def __init_subclass__(cls):
         """Used to register all non-abstract subclasses as a list in
         `QuantumSystem.subclasses`."""
@@ -101,7 +114,9 @@ class QuantumSystem(DispatchClient, ABC):
 
     def __str__(self) -> str:
         indent_length = 20
-        name_prepend = self._sys_type.ljust(indent_length, "-") + "|\n"
+        name_prepend = self._sys_type.ljust(indent_length, "-") + "| [{}]\n".format(
+            self._id_str
+        )
 
         output = ""
         for param_name in self.default_params().keys():
@@ -121,6 +136,14 @@ class QuantumSystem(DispatchClient, ABC):
     def __hash__(self):
         return super().__hash__()
 
+    def _autogenerate_id_str(self):
+        name = self._sys_type
+        return "{}_{}".format(name, QuantumSystem._instance_counter[name])
+
+    @property
+    def id_str(self):
+        return self._id_str
+
     def get_initdata(self) -> Dict[str, Any]:
         """Returns dict appropriate for creating/initializing a new Serializable
         object."""
@@ -141,6 +164,7 @@ class QuantumSystem(DispatchClient, ABC):
     def widget(self, params: Dict[str, Any] = None):
         """Use ipywidgets to modify parameters of class instance"""
         init_params = params or self.get_initdata()
+        init_params.pop("id_str", None)
         ui.create_widget(
             self.set_params, init_params, image_filename=self._image_filename
         )
@@ -466,10 +490,7 @@ class QubitBaseClass(QuantumSystem, ABC):
             bare_only=True,
             num_cpus=num_cpus,
         )
-        setattr(self, param_name, previous_paramval)
-        setattr(self, dispersion_name, previous_dispval)
-
-        eigenenergies = sweep["bare_esys"][0, :, :, 0].toarray()
+        eigenenergies = sweep["bare_evals"]["subsys":0].toarray()
 
         if levels is None:
             dispersions = np.empty((len(transitions), len(param_vals)))
@@ -484,6 +505,8 @@ class QubitBaseClass(QuantumSystem, ABC):
                 energy_j = eigenenergies[:, :, j]
                 dispersions[index] = np.max(energy_j, axis=0) - np.min(energy_j, axis=0)
 
+        setattr(self, param_name, previous_paramval)
+        setattr(self, dispersion_name, previous_dispval)
         return eigenenergies, dispersions
 
     def get_dispersion_vs_paramvals(
